@@ -20,8 +20,9 @@
 from gemma.gm.data._parquet import Parquet
 
 # `transforms=`
-from gemma.gm.data._transforms import AddContrastiveFields
-from gemma.gm.data._transforms import AddNextTokenPredictionFields
+from gemma.gm.data._tasks import ContrastiveTask
+from gemma.gm.data._tasks import Seq2SeqTask
+from gemma.gm.data._transforms import AddSeq2SeqFields
 from gemma.gm.data._transforms import DecodeBytes
 from gemma.gm.data._transforms import FormatText
 from gemma.gm.data._transforms import MapInts
@@ -29,5 +30,5 @@ from gemma.gm.data._transforms import Pad
 from gemma.gm.data._transforms import Tokenize
 
 # Functional API
-from gemma.gm.data._functional import make_next_token_prediction_fields
+from gemma.gm.data._functional import make_seq2seq_fields
 from gemma.gm.data._functional import pad
