@@ -21,14 +21,25 @@ from etils import epy as _epy
 
 with _epy.lazy_api_imports(globals()):
   # Gemma models
-  from gemma.gm.nn._transformer import Gemma2_2B
-  from gemma.gm.nn._transformer import Gemma2_9B
-  from gemma.gm.nn._transformer import Gemma2_27B
+  from gemma.gm.nn._gemma import Gemma2_2B
+  from gemma.gm.nn._gemma import Gemma2_9B
+  from gemma.gm.nn._gemma import Gemma2_27B
 
-  from gemma.gm.nn._lora import LoRAWrapper
+  from gemma.gm.nn._gemma import Gemma3_1B
+  from gemma.gm.nn._gemma import Gemma3_4B
+  from gemma.gm.nn._gemma import Gemma3_12B
+  from gemma.gm.nn._gemma import Gemma3_27B
+
+  # TODO(epot): Expose the Vision encoder model as standalone.
+
+  from gemma.gm.nn._lora import LoRA
+  from gemma.gm.nn._quantization import QuantizationAwareWrapper
+  from gemma.gm.nn._quantization import IntWrapper
   from gemma.gm.nn._policy import AnchoredPolicy
   from gemma.gm.nn._transformer import Transformer
 
   # Model outputs
   from gemma.gm.nn._transformer import Output
   from gemma.gm.nn._policy import AnchoredPolicyOutput
+
+  from gemma.gm.nn import config
