@@ -14,10 +14,13 @@
 
 """PEFT utils for `flax.linen`."""
 
-# pylint: disable=g-importing-member
+# pylint: disable=g-importing-member,g-bad-import-order
 
+# Module surgery utils
 from gemma.peft._interceptors import Interceptor
 from gemma.peft._interceptors import ModuleInterceptor
+
+# LoRA utils
 from gemma.peft._lora import LoRADense
 from gemma.peft._lora import LoRADenseAdapter
 from gemma.peft._lora import LoRAEinsum
@@ -26,3 +29,13 @@ from gemma.peft._tree_utils import fuse_params
 from gemma.peft._tree_utils import merge_params
 from gemma.peft._tree_utils import split_params
 from gemma.peft._tree_utils import unfuse_params
+
+# Quantization utils
+from gemma.peft._quantization_utils import QuantizationMethod
+from gemma.peft._quantization_utils import quantize
+from gemma.peft._quantization import simulate_quantize
+from gemma.peft._quantization import get_axis_to_reduce_from_einsum_str
+from gemma.peft._quantization import SimulateQuantizedDense
+from gemma.peft._quantization import SimulateQuantizedEinsum
+from gemma.peft._quantization import IntDense
+from gemma.peft._quantization import IntEinsum
